==> granite-server-cdi-3.0.0.GA-sources.jar: org/granite/tide/cdi/Identity.java <==
/**
 *   GRANITE DATA SERVICES
 *   Copyright (C) 2006-2013 GRANITE DATA SERVICES S.A.S.
 *
 *   This file is part of the Granite Data Services Platform.
 *
 *   Granite Data Services is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *
 *   Granite Data Services is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 *   General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 *   USA, or see <http://www.gnu.org/licenses/>.
 */
package org.granite.tide.cdi;

import org.granite.context.GraniteContext;
import org.granite.messaging.webapp.HttpGraniteContext;


/**
 * @author William DRAI
 */
public class Identity  {
        
    public String isLoggedIn() {
    	GraniteContext context = GraniteContext.getCurrentInstance();
    	if (context != null && ((HttpGraniteContext)context).getRequest().getUserPrincipal() != null)
    		return ((HttpGraniteContext)context).getRequest().getUserPrincipal().getName();    	
    	return null;
    }
    
    
    public boolean hasRole(String role) {
    	GraniteContext context = GraniteContext.getCurrentInstance();
    	if (context == null || !(context instanceof HttpGraniteContext))
    		return false;
    	
    	return ((HttpGraniteContext)context).getRequest().isUserInRole(role);
    }
}

==> granite-server-cdi-3.1.0.GA-sources.jar: org/granite/tide/cdi/Identity.java <==
/**
 *   GRANITE DATA SERVICES
 *   Copyright (C) 2006-2014 GRANITE DATA SERVICES S.A.S.
 *
 *   This file is part of the Granite Data Services Platform.
 *
 *   Granite Data Services is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *
 *   Granite Data Services is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 *   General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 *   USA, or see <http://www.gnu.org/licenses/>.
 */
package org.granite.tide.cdi;

import org.granite.context.GraniteContext;
import org.granite.messaging.webapp.HttpGraniteContext;
import org.granite.tide.security.ServerIdentity;


/**
 * @author William DRAI
 */
public class Identity implements ServerIdentity {
        
    @Override
    public String isLoggedIn() {
    	GraniteContext context = GraniteContext.getCurrentInstance();
    	if (context != null && ((HttpGraniteContext)context).getRequest().getUserPrincipal() != null)
    		return ((HttpGraniteContext)context).getRequest().getUserPrincipal().getName();    	
    	return null;
    }
    
    
    public boolean hasRole(String role) {
    	GraniteContext context = GraniteContext.getCurrentInstance();
    	if (context == null || !(context instanceof HttpGraniteContext))
    		return false;
    	
    	return ((HttpGraniteContext)context).getRequest().isUserInRole(role);
    }
}
